// Image class header
#pragma once

#include "GraphicsResource.h"
#include "VideoMemoryAllocator.h"

namespace nf::client::render {
    enum class ImageType {
        Texture,
        DepthAttachment
    };

    class Image : GraphicsResource {
    public:
        Image(ImageType type, const VkDevice& device, VideoMemoryAllocator& allocator, const VkCommandPool& commandPool, const VkQueue& queue, const std::string& imageData, VkExtent2D attachmentExtent = {});

        const VkImageView& getView() const;

        ~Image();
    private:
        void createTextureImage(VkFormat imageFormat, const VkCommandPool& commandPool, const VkQueue& queue, const std::string& imageData);
        void createImage(VkFormat imageFormat, VkExtent2D& size, VkImageUsageFlags usage);
        void createImageView(VkFormat format);

        VideoMemoryAllocator& m_allocator;

        VkImage m_handle;
        VideoMemoryAllocation m_allocation;
        VkImageView m_view;
    };
}
